==> libgnomedb-1.3.3.tar.bz2: libgnomedb-1.3.3/libgnomedb/graph/gnome-db-graph-query.h <==
/* gnome-db-graph-query.h
 *
 * Copyright (C) 2004 Vivien Malerba
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */


#ifndef __GNOME_DB_GRAPH_QUERY_H_
#define __GNOME_DB_GRAPH_QUERY_H_

#include "gnome-db-graph.h"

G_BEGIN_DECLS

#define GNOME_DB_GRAPH_QUERY_TYPE          (gnome_db_graph_query_get_type())
#define GNOME_DB_GRAPH_QUERY(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_graph_query_get_type(), GnomeDbGraphQuery)
#define GNOME_DB_GRAPH_QUERY_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_graph_query_get_type (), GnomeDbGraphQueryClass)
#define IS_GNOME_DB_GRAPH_QUERY(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_graph_query_get_type ())

/* error reporting */
extern GQuark gnome_db_graph_query_error_quark (void);
#define GNOME_DB_GRAPH_QUERY_ERROR gnome_db_graph_query_error_quark ()


/* struct for the object's data */
struct _GnomeDbGraphQuery
{
	GnomeDbGraph               object;
	GnomeDbGraphQueryPrivate  *priv;
};

/* struct for the object's class */
struct _GnomeDbGraphQueryClass
{
	GnomeDbGraphClass   class;
};

guint            gnome_db_graph_query_get_type            (void);

GObject         *gnome_db_graph_query_new                 (GnomeDbQuery *query);
void             gnome_db_graph_query_sync_targets        (GnomeDbGraphQuery *graph);

G_END_DECLS

#endif

==> libgnomedb-1.3.4.tar.bz2: libgnomedb-1.3.4/libgnomedb/graph/gnome-db-graph-query.h <==
/* gnome-db-graph-query.h
 *
 * Copyright (C) 2004 Vivien Malerba
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */


#ifndef __GNOME_DB_GRAPH_QUERY_H_
#define __GNOME_DB_GRAPH_QUERY_H_

#include "gnome-db-graph.h"

G_BEGIN_DECLS

#define GNOME_DB_GRAPH_QUERY_TYPE          (gnome_db_graph_query_get_type())
#define GNOME_DB_GRAPH_QUERY(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_graph_query_get_type(), GnomeDbGraphQuery)
#define GNOME_DB_GRAPH_QUERY_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_graph_query_get_type (), GnomeDbGraphQueryClass)
#define IS_GNOME_DB_GRAPH_QUERY(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_graph_query_get_type ())

/* error reporting */
extern GQuark gnome_db_graph_query_error_quark (void);
#define GNOME_DB_GRAPH_QUERY_ERROR gnome_db_graph_query_error_quark ()


/* struct for the object's data */
struct _GnomeDbGraphQuery
{
	GnomeDbGraph               object;
	GnomeDbGraphQueryPrivate  *priv;
};

/* struct for the object's class */
struct _GnomeDbGraphQueryClass
{
	GnomeDbGraphClass   class;
};

GType            gnome_db_graph_query_get_type            (void);

GObject         *gnome_db_graph_query_new                 (GnomeDbQuery *query);
void             gnome_db_graph_query_sync_targets        (GnomeDbGraphQuery *graph);

G_END_DECLS

#endif
